Do not generate methods if the component is abstract.

git-svn-id: https://svn.apache.org/repos/asf/felix/trunk@572584 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/scrplugin/src/main/java/org/apache/felix/scrplugin/SCRDescriptorMojo.java b/scrplugin/src/main/java/org/apache/felix/scrplugin/SCRDescriptorMojo.java
index c351e4f..760c282 100644
--- a/scrplugin/src/main/java/org/apache/felix/scrplugin/SCRDescriptorMojo.java
+++ b/scrplugin/src/main/java/org/apache/felix/scrplugin/SCRDescriptorMojo.java
@@ -525,8 +525,8 @@
                 ref.setUnbind(unbindValue);
             }
             // if this is a field we look for the bind/unbind methods
-            // and create them if they are not availabe
-            if ( this.generateAccessors ) {
+            // and create them if they are not availabe and the component is not abstract
+            if ( !component.isAbstract() && this.generateAccessors ) {
                 if ( reference.getField() != null && component.getJavaClassDescription() instanceof ModifiableJavaClassDescription ) {
                     boolean createBind = false;
                     boolean createUnbind = false;